Learn R Programming

plmDE (version 1.0)

mostDE: Find Genes with the Most Evidence for Differential Expression

Description

Returns the most significant genes in a DEresults object.

Usage

mostDE(results, n = 10)

Arguments

results
A DEresults object containing the results of a test for differential gene expression.
n
An integer describing the number of highest-significance genes to list.

Value

Returns a data frame of the top n genes ordered by significance along with their adjusted p-values under the test.

See Also

fitGAPLM, topTable

Examples

Run this code
## Run a test for differential gene expression:
ExpressionData = as.data.frame(matrix(abs(rnorm(10000, 1, 1.5)), ncol = 100))
names(ExpressionData) = sapply(1:100, function(x) paste("Sample", x))
Genes = sapply(1:100, function(x) paste("Gene", x))
DataInfo = data.frame(sample = names(ExpressionData), group = c(rep("Control", 50),
 rep("Diseased", 50)), weight = abs(rnorm(100, 50, 20)), severity = c(rep(0, 50),
 abs(rnorm(50, 100, 20))))
plmDEobject = plmDEmodel(Genes, ExpressionData, DataInfo)
test = fitGAPLM(plmDEobject, continuousCovariates.fullModel = c("weight", "severity"),
 compareToReducedModel = TRUE, indicators.reducedModel = NULL, 
continuousCovariates.reducedModel = "weight")

## find 20 genes with most evidence for differential expression:
mostDE(test)

Run the code above in your browser using DataLab