Learn R Programming

plmDE (version 1.0)

plmDEmodel: Constructor for objects of type plmDE

Description

Creates an object which can hold expression data and other measurements of interest.

Usage

plmDEmodel(genes, ...)

Arguments

genes
Object containing the genes of interest from which an object of type plmDE should be made.
...
additional parameters

See Also

plmDEmodel.default