Rdocumentation
powered by
Learn R Programming
plmDE (version 1.0)
hist.DEresults: Create a Histogram of P-values
Description
Plots the distribution of p-values resulting from testing multiple genes for differential expression.
Usage
"hist"(x, ...)
Arguments
x
An object of type
DEresults
containing the test results for each gene.
...
Additional parameters to be passed to
hist
References
Pounds, S. B. Estimation and control of multiple testing error rates for microarray studies. Brief Bioinformatics
7
(1), 25-36 (2006).